@@ -8,10 +8,16 @@ from typing import Optional
 class ComposoError(Exception):
     """Base exception for all Composo SDK errors"""
 
-    def __init__(self, message: str, status_code: Optional[int] = None):
+    def __init__(
+        self,
+        message: str,
+        status_code: Optional[int] = None,
+        response_body: Optional[str] = None,
+    ):
         super().__init__(message)
         self.message = message
         self.status_code = status_code
+        self.response_body = response_body
 
 
 class RateLimitError(ComposoError):
@@ -44,7 +50,9 @@ class TimeoutError(ComposoError):
     pass
 
 
-def get_exception_for_status_code(status_code: int, message: str = "") -> ComposoError:
+def get_exception_for_status_code(
+    status_code: int, message: str = "", response_body: Optional[str] = None
+) -> ComposoError:
     """Factory function to create appropriate exceptions based on HTTP status codes"""
 
     exception_map = {
@@ -56,4 +64,4 @@ def get_exception_for_status_code(status_code: int, message: str = "") -> Compos
     }
 
     exception_class = exception_map.get(status_code, ComposoError)
-    return exception_class(message, status_code)
+    return exception_class(message, status_code, response_body)
