@@ -2,21 +2,14 @@
 Data models for Composo SDK
 """
 
-from .messages import Message
-from .evaluation import (
-    StandardMessageData,
-    RequestBase,
-    RewardRequest,
-    BinaryEvaluationRequest,
-    ScoreResponse,
-    BinaryEvaluationResponse,
-)
+from openai.types.chat.chat_completion_message_param import ChatCompletionMessageParam
+from .requests import RequestBase, RewardRequest, BinaryEvaluationRequest
+from .responses import ScoreResponse, BinaryEvaluationResponse
 from .client_models import EvaluationRequest, EvaluationResponse
 from .criteria import CriteriaSet
 
 __all__ = [
-    "Message",
-    "StandardMessageData",
+    "ChatCompletionMessageParam",
     "RequestBase",
     "RewardRequest",
     "BinaryEvaluationRequest",
